@@ -6,6 +6,7 @@ import threading
 import re
 import fileinput
 from collections import namedtuple
+from pwd import getpwuid
 from time import time
 from datetime import datetime
 from random import choice
@@ -48,7 +49,7 @@ from .key_bindings import mycli_bindings
 from .lexer import MyCliLexer
 from .__init__ import __version__
 from .compat import WIN
-from .packages.filepaths import dir_path_exists
+from .packages.filepaths import dir_path_exists, guess_socket_location
 
 import itertools
 
@@ -65,7 +66,7 @@ except ImportError:
 try:
     import paramiko
 except ImportError:
-    paramiko = False
+    from mycli.packages.paramiko_stub import paramiko
 
 # Query tuples are used for maintaining history
 Query = namedtuple('Query', ['query', 'successful', 'mutating'])
@@ -317,7 +318,7 @@ class MyCli(object):
         """
         cnf = read_config_files(files, list_values=False)
 
-        sections = ['client']
+        sections = ['client', 'mysqld']
         if self.login_path and self.login_path != 'client':
             sections.append(self.login_path)
 
@@ -382,10 +383,11 @@ class MyCli(object):
         # Fall back to config values only if user did not specify a value.
 
         database = database or cnf['database']
-        if port or host:
+        # Socket interface not supported for SSH connections
+        if port or host or ssh_host or ssh_port:
             socket = ''
         else:
-            socket = socket or cnf['socket']
+            socket = socket or cnf['socket'] or guess_socket_location()
         user = user or cnf['user'] or os.getenv('USER')
         host = host or cnf['host']
         port = port or cnf['port']
@@ -430,11 +432,11 @@ class MyCli(object):
                     raise e
 
         try:
-            if (socket is host is port is None) and not WIN:
-                # Try a sensible default socket first (simplifies auth)
-                # If we get a connection error, try tcp/ip localhost
+            if not WIN and socket:
+                socket_owner = getpwuid(os.stat(socket).st_uid).pw_name
+                self.echo(
+                    f"Connecting to socket {socket}, owned by user {socket_owner}")
                 try:
-                    socket = '/var/run/mysqld/mysqld.sock'
                     _connect()
                 except OperationalError as e:
                     # These are "Can't open socket" and 2x "Can't connect"
@@ -995,6 +997,9 @@ class MyCli(object):
 @click.option('--ssh-port', default=22, help='Port to connect to ssh server.')
 @click.option('--ssh-password', help='Password to connect to ssh server.')
 @click.option('--ssh-key-filename', help='Private key filename (identify file) for the ssh connection.')
+@click.option('--ssh-config-path', help='Path to ssh configuration.',
+              default=os.path.expanduser('~') + '/.ssh/config')
+@click.option('--ssh-config-host', help='Host to connect to ssh server reading from ssh configuration.')
 @click.option('--ssl-ca', help='CA file in PEM format.',
               type=click.Path(exists=True))
 @click.option('--ssl-capath', help='CA directory.')
@@ -1016,6 +1021,8 @@ class MyCli(object):
               help='Use DSN configured into the [alias_dsn] section of myclirc file.')
 @click.option('--list-dsn', 'list_dsn', is_flag=True,
         help='list of DSN configured into the [alias_dsn] section of myclirc file.')
+@click.option('--list-ssh-config', 'list_ssh_config', is_flag=True,
+              help='list ssh configurations in the ssh config (requires paramiko).')
 @click.option('-R', '--prompt', 'prompt',
               help='Prompt format (Default: "{0}").'.format(
                   MyCli.default_prompt))
@@ -1048,7 +1055,7 @@ def cli(database, user, host, port, socket, password, dbname,
         ssl_ca, ssl_capath, ssl_cert, ssl_key, ssl_cipher,
         ssl_verify_server_cert, table, csv, warn, execute, myclirc, dsn,
         list_dsn, ssh_user, ssh_host, ssh_port, ssh_password,
-        ssh_key_filename):
+        ssh_key_filename, list_ssh_config, ssh_config_path, ssh_config_host):
     """A MySQL terminal client with auto-completion and syntax highlighting.
 
     \b
@@ -1085,6 +1092,16 @@ def cli(database, user, host, port, socket, password, dbname,
             else:
                 click.secho(alias)
         sys.exit(0)
+    if list_ssh_config:
+        ssh_config = read_ssh_config(ssh_config_path)
+        for host in ssh_config.get_hostnames():
+            if verbose:
+                host_config = ssh_config.lookup(host)
+                click.secho("{} : {}".format(
+                    host, host_config.get('hostname')))
+            else:
+                click.secho(host)
+        sys.exit(0)
     # Choose which ever one has a valid value.
     database = dbname or database
 
@@ -1135,13 +1152,17 @@ def cli(database, user, host, port, socket, password, dbname,
         if not port:
             port = uri.port
 
-    if not paramiko and ssh_host:
-        click.secho(
-            "Cannot use SSH transport because paramiko isn't installed, "
-            "please install paramiko or don't use --ssh-host=",
-            err=True, fg="red"
-        )
-        exit(1)
+    if ssh_config_host:
+        ssh_config = read_ssh_config(
+            ssh_config_path
+        ).lookup(ssh_config_host)
+        ssh_host = ssh_host if ssh_host else ssh_config.get('hostname')
+        ssh_user = ssh_user if ssh_user else ssh_config.get('user')
+        if ssh_config.get('port') and ssh_port == 22:
+            # port has a default value, overwrite it if it's in the config
+            ssh_port = int(ssh_config.get('port'))
+        ssh_key_filename = ssh_key_filename if ssh_key_filename else ssh_config.get(
+            'identityfile', [None])[0]
 
     ssh_key_filename = ssh_key_filename and os.path.expanduser(ssh_key_filename)
 
@@ -1252,6 +1273,7 @@ def is_mutating(status):
                     'replace', 'truncate', 'load', 'rename'])
     return status.split(None, 1)[0].lower() in mutating
 
+
 def is_select(status):
     """Returns true if the first word in status is 'select'."""
     if not status:
@@ -1276,5 +1298,26 @@ def edit_and_execute(event):
     buff.open_in_editor(validate_and_handle=False)
 
 
+def read_ssh_config(ssh_config_path):
+    ssh_config = paramiko.config.SSHConfig()
+    try:
+        with open(ssh_config_path) as f:
+            ssh_config.parse(f)
+    # Paramiko prior to version 2.7 raises Exception on parse errors.
+    # In 2.7 it has become paramiko.ssh_exception.SSHException,
+    # but let's catch everything for compatibility
+    except Exception as err:
+        click.secho(
+            f'Could not parse SSH configuration file {ssh_config_path}:\n{err} ',
+            err=True, fg='red'
+        )
+        sys.exit(1)
+    except FileNotFoundError as e:
+        click.secho(str(e), err=True, fg='red')
+        sys.exit(1)
+    else:
+        return ssh_config
+
+
 if __name__ == "__main__":
     cli()
